@@ -11,7 +11,9 @@ void iindex(int *iindex,
   for (s=0;s<(*NS-1);s++){
     i=0;
     for (i=0; i<*N;i++){
-      if (L[i]<=U[s+1] && R[i]>=U[s]){
+      if ((L[i]==R[i] && L[i]==U[s+1]) /* exact obs */
+	  ||
+	  (L[i]<U[s+1] && R[i]>U[s])){   /* [U[s],U[s+1]] intersects [L[i],R[i]] */
 	iindex[k] = i+1;
 	k++;
       }
